@@ -12,6 +12,9 @@ get_BiGG <- function(address){
   if(!requireNamespace('jsonlite', quietly = TRUE)){
     stop('This function requires jsonlite. Please install it before continuing')
   }
+  if(!requireNamespace('curl', quietly = TRUE)){
+    stop('This function requires jsonlite. Please install it before continuing')
+  }
   
   
   json_mod <- jsonlite::fromJSON(address)
@@ -28,12 +31,8 @@ get_BiGG <- function(address){
     ) %>%
     mutate(obj_coef = coalesce(.data$objective_coefficient, 0))
   
-  res$mets <- json_mod$metabolites %>% 
-    purrr::keep(is.vector) %>%
-    transmute(chemical = .data$id,
-              compartment = .data$compartment,
-              name = .data$name) %>%
-    recompose_metabolites()
+  res$mets <- json_mod$metabolites %>%
+    select(met = id)
   
   res$stoich <- json_mod$reactions$metabolites %>%
     mutate(abbreviation = json_mod$reactions$id) %>%
@@ -41,4 +40,26 @@ get_BiGG <- function(address){
   
   return(res)
   
+}
+
+#' Validate an expanded model
+#' 
+#' @param reactions_expanded the expanded model to check
+#' 
+#' @return TRUE
+#' 
+#' @import assertthat 
+validate_expanded <- function(reactions_expanded){
+  
+  assert_that(
+    'data.frame' %in% class(reactions_expanded$rxns),
+    reactions_expanded$rxns %has_name% 'abbreviation',
+    reactions_expanded$rxns %has_name% 'uppbnd',
+    reactions_expanded$rxns %has_name% 'lowbnd',
+    reactions_expanded$rxns %has_name% 'obj_coef',
+    setequal(reactions_expanded$stoich$abbreviation, reactions_expanded$rxns$abbreviation),
+    setequal(reactions_expanded$stoich$met, reactions_expanded$mets$met)
+  )
+  
+  return(TRUE)
 }
\ No newline at end of file
